package com.boman.web.core.mapper;

import com.boman.domain.QianshanGrid;
import org.apache.ibatis.annotations.Param;

import java.util.List;


/**
 * 潜山网格信息Mapper接口
 *
 * @author ruoyi
 * @date 2022-06-20
 */
public interface QianshanGridMapper {
    /**
     * 查询潜山网格信息
     *
     * @param id 潜山网格信息主键
     * @return 潜山网格信息
     */
    public QianshanGrid selectQianshanGridById(Long id);

    /**
     * 查询潜山网格信息列表
     *
     * @param qianshanGrid 潜山网格信息
     * @return 潜山网格信息集合
     */
    public List<QianshanGrid> selectQianshanGridList(QianshanGrid qianshanGrid);

    /**
     * 新增潜山网格信息
     *
     * @param qianshanGrid 潜山网格信息
     * @return 结果
     */
    public int insertQianshanGrid(QianshanGrid qianshanGrid);

    /**
     * 修改潜山网格信息
     *
     * @param qianshanGrid 潜山网格信息
     * @return 结果
     */
    public int updateQianshanGrid(QianshanGrid qianshanGrid);

    /**
     * 删除潜山网格信息
     *
     * @param id 潜山网格信息主键
     * @return 结果
     */
    public int deleteQianshanGridById(Long id);

    /**
     * 批量删除潜山网格信息
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteQianshanGridByIds(Long[] ids);

    List<QianshanGrid> validateHasChirld(@Param("qianshanGrids") List<QianshanGrid> qianshanGrids);
}
